# wsipre

**W**hole-**S**lide **I**mage **PRE**processing

**wsipre** is a small Python package to handle whole-slide images (WSI; also
known as virtual slides) with region-level annotations.

**wsipre** can be installed from PyPI as shown below. For more detail check out
the [docs](https://luisvalesilva.com/wsipre/_build/html/index.html).

```console
pip install wsipre
```


## License

This project is licensed under the terms of the MIT license. See [LICENSE](LICENSE) file for details.
